summaryrefslogtreecommitdiff
path: root/makima/src/daemon
diff options
context:
space:
mode:
authorsoryu <soryu@soryu.co>2026-02-01 02:39:19 +0000
committersoryu <soryu@soryu.co>2026-02-01 02:39:52 +0000
commitddd956118880d3416a5e8101dcee7f880cbdc444 (patch)
tree9406c510782f7f91c68b3d461ce46f6428a49072 /makima/src/daemon
parentd0062efd34dfc22c2d8cfee0a47431ac0c8adfda (diff)
downloadsoryu-makima/multi-phase-plan-fix.tar.gz
soryu-makima/multi-phase-plan-fix.zip
Diffstat (limited to 'makima/src/daemon')
-rw-r--r--makima/src/daemon/cli/server.rs6
-rw-r--r--makima/src/daemon/task/manager.rs4
2 files changed, 5 insertions, 5 deletions
diff --git a/makima/src/daemon/task/manager.rs b/makima/src/daemon/task/manager.rs
index e0437ce..bf495d9 100644
--- a/makima/src/daemon/task/manager.rs
+++ b/makima/src/daemon/task/manager.rs
@@ -598,7 +598,7 @@ rsync -av --exclude='.git' --exclude='.makima' "$FINAL_TASK_PATH/" ./
/// System prompt for supervisor tasks (contract orchestrators).
/// Supervisors monitor all tasks in a contract, create new tasks, and drive the contract to completion.
-const SUPERVISOR_SYSTEM_PROMPT: &str = r#"You are the SUPERVISOR for this contract. Your ONLY job is to coordinate work by spawning tasks, waiting for them to complete, and managing git operations.
+const SUPERVISOR_SYSTEM_PROMPT: &str = r###"You are the SUPERVISOR for this contract. Your ONLY job is to coordinate work by spawning tasks, waiting for them to complete, and managing git operations.
## CRITICAL RULES - READ CAREFULLY
@@ -960,7 +960,7 @@ After all tasks are "done" and merged, you MUST take the following actions:
---
-"#;
+"###;
/// System prompt for tasks that are part of a contract.
/// This tells the task about contract.sh and how to use it to interact with the contract.
diff --git a/makima/src/daemon/cli/server.rs b/makima/src/daemon/cli/server.rs
index 81dafc9..adb765d 100644
--- a/makima/src/daemon/cli/server.rs
+++ b/makima/src/daemon/cli/server.rs
@@ -33,9 +33,9 @@ pub struct ServerArgs {
)]
pub sortformer_model_path: String,
- /// Path to Qwen3-TTS model directory
- #[arg(long, env = "QWEN3_TTS_DIR", default_value = "models/qwen3-tts")]
- pub qwen3_tts_dir: String,
+ /// Path to Chatterbox TTS model directory
+ #[arg(long, env = "CHATTERBOX_MODEL_DIR", default_value = "models/chatterbox-turbo")]
+ pub chatterbox_model_dir: String,
/// PostgreSQL connection URI
#[arg(long, env = "POSTGRES_CONNECTION_URI")]